@@ -18,7 +18,7 @@
 Various useful commands for working with bzr.
 """
 
-from bzrlib import ignores
+from bzrlib import ignores, option
 from bzrlib.commands import plugin_cmds
 from version import version_info, __version__
 
@@ -31,7 +31,8 @@ commands = {
     'cmd_branch_history': [],
     'cmd_cbranch': [],
     'cmd_cdiff': [],
-    'cmd_clean_tree': [],
+    'cmd_conflict_diff': [],
+    'cmd_create_mirror': [],
     'cmd_fetch_ghosts': ['fetch-missing'],
     'cmd_graph_ancestry': [],
     'cmd_import': [],
@@ -39,11 +40,11 @@ commands = {
     'cmd_multi_pull': [],
     'cmd_patch': [],
     'cmd_rspush': [],
-    'cmd_shelf': [],
+    'cmd_shelf1': [],
     'cmd_shell': [],
-    'cmd_shelve1': ['shelve'],
+    'cmd_shelve1': [],
     'cmd_trees': [],
-    'cmd_unshelve1': ['unshelve'],
+    'cmd_unshelve1': [],
     'cmd_zap': [],
 }
 
@@ -52,28 +53,42 @@ for cmd_name, aliases in commands.items():
     plugin_cmds.register_lazy(cmd_name, aliases,
                               'bzrlib.plugins.bzrtools.command_classes')
 
+
 plugin_cmds.register_lazy('cmd_heads', [], 'bzrlib.plugins.bzrtools.heads')
 
+
+option.diff_writer_registry.register_lazy(
+    'auto-color', 'bzrlib.plugins.bzrtools.colordiff', 'auto_diff_writer',
+    'Colorized diffs, if supported',
+)
+option.diff_writer_registry.register_lazy(
+    'color', 'bzrlib.plugins.bzrtools.colordiff', 'DiffWriter',
+    'Colorized diffs',
+)
+option.diff_writer_registry.default_key = 'auto-color'
+
+
 def test_suite():
     from bzrlib.tests.TestUtil import TestLoader
     import tests
     from doctest import DocTestSuite, ELLIPSIS
     from unittest import TestSuite
     import bzrtools
-    import tests.clean_tree
     import tests.test_dotgraph
     import tests.is_clean
     import tests.test_cbranch
+    import tests.test_conflict_diff
+    from bzrlib.plugins.bzrtools.tests import test_fetch_ghosts
     import tests.test_link_tree
     import tests.test_patch
     import tests.test_rspush
+    import tests.test_mirror
     import tests.upstream_import
     import zap
     import tests.blackbox
     import tests.shelf_tests
     result = TestSuite()
     result.addTest(DocTestSuite(bzrtools, optionflags=ELLIPSIS))
-    result.addTest(tests.clean_tree.test_suite())
     result.addTest(tests.test_suite())
     result.addTest(TestLoader().loadTestsFromModule(tests.shelf_tests))
     result.addTest(tests.blackbox.test_suite())
@@ -81,8 +96,11 @@ def test_suite():
     result.addTest(zap.test_suite())
     result.addTest(TestLoader().loadTestsFromModule(tests.test_dotgraph))
     result.addTest(TestLoader().loadTestsFromModule(tests.is_clean))
+    result.addTest(TestLoader().loadTestsFromModule(test_fetch_ghosts))
     result.addTest(TestLoader().loadTestsFromModule(tests.test_link_tree))
     result.addTest(TestLoader().loadTestsFromModule(tests.test_patch))
     result.addTest(TestLoader().loadTestsFromModule(tests.test_rspush))
     result.addTest(TestLoader().loadTestsFromModule(tests.test_cbranch))
+    result.addTest(TestLoader().loadTestsFromModule(tests.test_conflict_diff))
+    result.addTest(TestLoader().loadTestsFromModule(tests.test_mirror))
     return result
