@@ -16,6 +16,8 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+import errno
+
 import bzrlib
 
 from bzrlib.lazy_import import lazy_import
@@ -38,45 +40,12 @@ from bzrlib.commands import get_cmd_object
 from bzrlib.errors import BzrCommandError
 import bzrlib.ignores
 from bzrlib.trace import note
-from bzrlib.option import Option
+from bzrlib.option import Option, RegistryOption
+from bzrlib.workingtree import WorkingTree
 
 from command import BzrToolsCommand
 
 
-class cmd_clean_tree(BzrToolsCommand):
-    """Remove unwanted files from working tree.
-
-    By default, only unknown files, not ignored files, are deleted.  Versioned
-    files are never deleted.
-
-    Another class is 'detritus', which includes files emitted by bzr during
-    normal operations and selftests.  (The value of these files decreases with
-    time.)
-
-    If no options are specified, unknown files are deleted.  Otherwise, option
-    flags are respected, and may be combined.
-
-    To check what clean-tree will do, use --dry-run.
-    """
-    takes_options = [Option('ignored', help='Delete all ignored files.'),
-                     Option('detritus', help='Delete conflict files, merge'
-                            ' backups, and failed selftest dirs.'),
-                     Option('unknown',
-                            help='Delete files unknown to bzr (default).'),
-                     Option('dry-run', help='Show files to delete instead of'
-                            ' deleting them.'),
-                     Option('force', help='Do not prompt before deleting.')]
-    def run(self, unknown=False, ignored=False, detritus=False, dry_run=False,
-            force=False):
-        from clean_tree import clean_tree
-        if not (unknown or ignored or detritus):
-            unknown = True
-        if dry_run:
-            force = True
-        clean_tree('.', unknown=unknown, ignored=ignored, detritus=detritus, 
-                   dry_run=dry_run, no_prompt=force)
-
-
 class cmd_graph_ancestry(BzrToolsCommand):
     """Produce ancestry graphs using dot.
     
@@ -151,7 +120,7 @@ class cmd_fetch_ghosts(BzrToolsCommand):
     takes_options = [Option('no-fix', help="Skip additional synchonization.")]
     def run(self, branch=None, no_fix=False):
         from fetch_ghosts import fetch_ghosts
-        fetch_ghosts(branch, no_fix)
+        fetch_ghosts(branch, do_reconcile=not no_fix)
 
 strip_help="""Strip the smallest prefix containing num leading slashes  from \
 each file name found in the patch file."""
@@ -161,7 +130,8 @@ class cmd_patch(BzrToolsCommand):
     """Apply a named patch to the current tree.
     """
     takes_args = ['filename?']
-    takes_options = [Option('strip', type=int, help=strip_help),
+    takes_options = [Option('strip', type=int, short_name='p',
+                            help=strip_help),
                      Option('silent', help='Suppress chatter.')]
     def run(self, filename=None, strip=None, silent=False):
         from patch import patch
@@ -199,10 +169,9 @@ class cmd_shelve1(BzrToolsCommand):
     don't depend on each other.
 
     While you have patches on the shelf you can view and manipulate them with
-    the 'shelf' command. Run 'bzr shelf -h' for more info.
+    the 'shelf1' command. Run 'bzr shelf1 -h' for more info.
     """
 
-    aliases = ['shelve']
     takes_args = ['file*']
     takes_options = [Option('message',
             help='A message to associate with the shelved changes.',
@@ -226,7 +195,7 @@ class cmd_shelve1(BzrToolsCommand):
         return 0
 
 
-# The following classes are only used as subcommands for 'shelf', they're
+# The following classes are only used as subcommands for 'shelf1', they're
 # not to be registered directly with bzr.
 
 class cmd_shelf_list(bzrlib.commands.Command):
@@ -268,7 +237,7 @@ class cmd_shelf_upgrade(bzrlib.commands.Command):
         self.shelf.upgrade()
 
 
-class cmd_shelf(BzrToolsCommand):
+class cmd_shelf1(BzrToolsCommand):
     """Perform various operations on your shelved patches. See also shelve1."""
     takes_args = ['subcommand', 'args*']
 
@@ -342,7 +311,6 @@ class cmd_unshelve1(BzrToolsCommand):
 
     See 'shelve1' for more information.
     """
-    aliases = ['unshelve']
     takes_options = [
             Option('all', help='Unshelve all changes without prompting.'),
             Option('force', help='Force unshelving even if errors occur.'),
@@ -534,13 +502,39 @@ class cmd_cdiff(BzrToolsCommand):
     """A color version of bzr's diff"""
     takes_args = property(lambda x: get_cmd_object('diff').takes_args)
     takes_options = list(get_cmd_object('diff').takes_options) + [
+        RegistryOption.from_kwargs('color',
+            'Color mode to use.',
+            title='Color Mode', value_switches=False, enum_switch=True,
+            never='Never colorize output.',
+            auto='Only colorize output if terminal supports it and STDOUT is a'
+            ' TTY.',
+            always='Always colorize output (default).'),
         Option('check-style',
             help='Warn if trailing whitespace or spurious changes have been'
                  ' added.')]
 
-    def run(self, check_style=False, *args, **kwargs):
+    def run(self, color='always', check_style=False, *args, **kwargs):
         from colordiff import colordiff
-        colordiff(check_style, *args, **kwargs)
+        colordiff(color, check_style, *args, **kwargs)
+
+
+class cmd_conflict_diff(BzrToolsCommand):
+
+    """Compare a conflicted file against BASE."""
+
+    encoding_type = 'exact'
+    takes_args = ['file']
+    takes_options = [
+        RegistryOption.from_kwargs('direction', 'Direction of comparison.',
+            value_switches=True, enum_switch=False,
+            other='Compare OTHER against common base.',
+            this='Compare THIS against common base.')]
+
+    def run(self, file, direction='other'):
+        from bzrlib.plugins.bzrtools.colordiff import DiffWriter
+        from conflict_diff import conflict_diff
+        dw = DiffWriter(self.outf, check_style=False, color='auto')
+        conflict_diff(dw, file, direction)
 
 
 class cmd_rspush(BzrToolsCommand):
@@ -586,3 +580,20 @@ class cmd_link_tree(BzrToolsCommand):
                 source_tree.unlock()
         finally:
             target_tree.unlock()
+
+
+class cmd_create_mirror(BzrToolsCommand):
+    """Create a mirror of another branch.
+
+    This is similar to `bzr branch`, but copies more settings, including the
+    submit branch and nickname.
+
+    It sets the public branch and parent of the target to the source location.
+    """
+
+    takes_args = ['source', 'target']
+
+    def run(self, source, target):
+        source_branch = Branch.open(source)
+        from bzrlib.plugins.bzrtools.mirror import create_mirror
+        create_mirror(source_branch, target, [])
