@@ -27,7 +27,7 @@ import sys
 from bzrlib import osutils
 from bzrlib.branch import Branch
 from bzrlib.config import config_dir, ensure_config_dir_exists
-from bzrlib.commands import get_cmd_object, get_all_cmds, get_alias
+from bzrlib.commands import get_cmd_object, all_command_names, get_alias
 from bzrlib.errors import BzrError
 from bzrlib.workingtree import WorkingTree
 
@@ -99,7 +99,8 @@ class PromptCmd(cmd.Cmd):
         self.identchars += '-'
         ensure_config_dir_exists()
         self.history_file = osutils.pathjoin(config_dir(), 'shell-history')
-        readline.set_completer_delims(string.whitespace)
+        whitespace = ''.join(c for c in string.whitespace if c < chr(127))
+        readline.set_completer_delims(whitespace)
         if os.access(self.history_file, os.R_OK) and \
             os.path.isfile(self.history_file):
             readline.read_history_file(self.history_file)
@@ -168,7 +169,12 @@ class PromptCmd(cmd.Cmd):
         self.default("help "+line)
 
     def default(self, line):
-        args = shlex.split(line)
+        try:
+            args = shlex.split(line)
+        except ValueError, e:
+            print 'Parse error:', e
+            return
+
         alias_args = get_alias(args[0])
         if alias_args is not None:
             args[0] = alias_args.pop(0)
@@ -223,10 +229,14 @@ class PromptCmd(cmd.Cmd):
 def run_shell():
     try:
         prompt = PromptCmd()
-        try:
-            prompt.cmdloop()
-        finally:
-            prompt.write_history()
+        while True:
+            try:
+                try:
+                    prompt.cmdloop()
+                except KeyboardInterrupt:
+                    print
+            finally:
+                prompt.write_history()
     except StopIteration:
         pass
 
@@ -280,10 +290,11 @@ def iter_dir_completions(arg):
 
 
 def iter_command_names(hidden=False):
-    for real_cmd_name, cmd_class in get_all_cmds():
-        if not hidden and cmd_class.hidden:
+    for real_cmd_name in all_command_names():
+        cmd_obj = get_cmd_object(real_cmd_name)
+        if not hidden and cmd_obj.hidden:
             continue
-        for name in [real_cmd_name] + cmd_class.aliases:
+        for name in [real_cmd_name] + cmd_obj.aliases:
             # Don't complete on aliases that are prefixes of the canonical name
             if name == real_cmd_name or not real_cmd_name.startswith(name):
                 yield name
