@@ -13,43 +13,14 @@ class TestBzrTools(TestCaseWithTransport):
     def touch(filename):
         file(filename, 'wb').write('')
 
-    def test_clean_tree(self):
-        self.run_bzr('init')
-        self.run_bzr('ignore *~')
-        self.run_bzr('ignore *.pyc')
-        self.touch('name')
-        self.touch('name~')
-        assert os.path.lexists('name~')
-        self.touch('name.pyc')
-        self.run_bzr('clean-tree --force')
-        assert os.path.lexists('name~')
-        assert not os.path.lexists('name')
-        self.touch('name')
-        self.run_bzr('clean-tree --detritus --force')
-        assert os.path.lexists('name')
-        assert not os.path.lexists('name~')
-        assert os.path.lexists('name.pyc')
-        self.run_bzr('clean-tree --ignored --force')
-        assert os.path.lexists('name')
-        assert not os.path.lexists('name.pyc')
-        self.run_bzr('clean-tree --unknown --force')
-        assert not os.path.lexists('name')
-        self.touch('name')
-        self.touch('name~')
-        self.touch('name.pyc')
-        self.run_bzr('clean-tree --unknown --ignored --force')
-        assert not os.path.lexists('name')
-        assert not os.path.lexists('name~')
-        assert not os.path.lexists('name.pyc')
-
     def test_shelve(self):
         self.run_bzr('init')
         self.run_bzr('commit -m uc --unchanged')
-        self.run_bzr('shelve -r 1 -m foo --all', retcode=3)
+        self.run_bzr('shelve1 -r 1 -m foo --all', retcode=3)
         file('foo', 'wb').write('foo')
         self.run_bzr('add foo')
         self.run_bzr('commit -m foo')
-        self.run_bzr('shelve -r 1 -m foo --all', retcode=0)
+        self.run_bzr('shelve1 -r 1 -m foo --all', retcode=0)
 
     def test_fetch_ghosts(self):
         self.run_bzr('init')
@@ -181,7 +152,8 @@ class TestBzrTools(TestCaseWithTransport):
 
     def test_cbranch_hardlink(self):
         self.requireFeature(HardlinkFeature)
-        source = self.make_branch_and_tree('source')
+        # Later formats don't support hardlinks.  Boo!
+        source = self.make_branch_and_tree('source', format='1.9')
         self.build_tree(['source/file'])
         source.add('file')
         source.commit('added file')
@@ -198,6 +170,14 @@ class TestBzrTools(TestCaseWithTransport):
         self.assertEqual(os.lstat(checkout2.abspath('file')).st_ino,
                          os.lstat(source.abspath('file')).st_ino)
 
+    def test_create_mirror(self):
+        source = self.make_branch_and_tree('source')
+        source.commit('message')
+        self.run_bzr('create-mirror source target')
+        target = branch.Branch.open('target')
+        self.assertEqual(source.last_revision(), target.last_revision())
+        self.assertEqual(source.branch.base, target.get_public_branch())
+
 
 def test_suite():
     return makeSuite(TestBzrTools)
